# Changelog

## 1.2.0 (2025-05-31)

Full Changelog: [v1.1.0...v1.2.0](https://github.com/AtomTickets/discovery-search/compare/v1.1.0...v1.2.0)

### Features

* **api:** update via SDK Studio ([9d63aa3](https://github.com/AtomTickets/discovery-search/commit/9d63aa30c857288664c05e5847fb17880a1942ce))

## 1.1.0 (2025-05-31)

Full Changelog: [v1.0.1...v1.1.0](https://github.com/AtomTickets/discovery-search/compare/v1.0.1...v1.1.0)

### Features

* **api:** update via SDK Studio ([f69cb25](https://github.com/AtomTickets/discovery-search/commit/f69cb254cf19431a55756558ca351199a33edb65))

## 1.0.1 (2025-05-31)

Full Changelog: [v1.0.0...v1.0.1](https://github.com/AtomTickets/discovery-search/compare/v1.0.0...v1.0.1)

### Chores

* **internal:** version bump ([13b1080](https://github.com/AtomTickets/discovery-search/commit/13b10805bbfa68bf4faf267c485c67eb1f9234b6))

## 1.0.0 (2025-05-30)

Full Changelog: [v0.0.1-alpha.0...v1.0.0](https://github.com/AtomTickets/discovery-search/compare/v0.0.1-alpha.0...v1.0.0)

### Chores

* update SDK settings ([b0e79b5](https://github.com/AtomTickets/discovery-search/commit/b0e79b5b02a63d5746bb07edb1e822ee344de1cc))
* update SDK settings ([bce5884](https://github.com/AtomTickets/discovery-search/commit/bce5884fcf3528303658079e4f07324b5c231e56))
